@@ -13,7 +13,9 @@ from io import StringIO
 from math import floor
 from alacorder import run
 from alacorder import alac
+import warnings
 
+warnings.filterwarnings("ignore")
 
 print('''
 
@@ -24,7 +26,7 @@ print('''
 	/_/  |_/_/\\__,_/\\___/\\____/_/   \\__,_/\\___/_/     
 																																														
 		
-		ALACORDER beta 0.5.63
+		ALACORDER beta 0.5.9
 		by Sam Robson	
 
 
@@ -35,8 +37,7 @@ A.	EXPORTING DETAILED CASE INFORMATION AS A TABLE
 	Create detailed cases table with convictions, charges,
 	fees, and voting rights restoration information. 
 
-	Inputs:		PDF Directory (./path/to/pdfs) or 
-			Archive (.pkl, .csv, .xls, .json)
+	Inputs:		PDF Directory (./path/to/pdfs) or Archive (.pkl, .csv, .xls, .json)
 
 	Outputs:	Detailed Cases Table 
  			(.pkl, .csv, .xls, .dta, .json) 
@@ -44,16 +45,15 @@ A.	EXPORTING DETAILED CASE INFORMATION AS A TABLE
 
 B.	CREATE A FULL TEXT ARCHIVE FROM PDF CASES
 
-	Search directory for PDF files, collect full text
-	and compress into archive. Archives can be processed
-	into tables with mode A or manually with alac.
+	Search directory for PDF files, collect full text and compress into archive.
+	Archives can be processed into tables with mode A or manually with alac.
 
 	Inputs:		PDF Directory (./path/to/pdfs)
 
-	Outputs:	Archive (.pkl, .csv, .xls, .json) or
-			non-importable text file (.txt)
+	Outputs:	Archive (.pkl, .csv, .xls, .json) or non-importable text file (.txt)
 
->> Enter A or B: ''')
+>> Enter A or B:
+''')
 
 ab = "".join(input()).strip()
 
@@ -64,14 +64,16 @@ if ab == "A":
 			ex.	/full/path/to/pdf/folder/
 			ex.	/full/path/to/fulltextarchive.pkl
 
-	>> Input path: ''')
+	>> Input path:
+''')
 elif ab == "B":
 	print(f'''
 
 	>>	Enter the input PDF directory path, including a forward-slash.
 			ex.	/full/path/to/pdf/folder/
 
-	>> Input path: ''')
+	>> Input path: 
+''')
 else:
 	raise Exception("Not a valid input!")
 
@@ -88,7 +90,8 @@ if ab == "A":
 			ex.	/full/path/to/casestable.xls
 			ex.	/full/path/to/cases.csv
 
-	>> Output path: ''')
+	>> Output path: 
+''')
 elif ab == "B":
 	print(f'''
 
@@ -96,7 +99,8 @@ elif ab == "B":
 			ex.	/full/path/to/fulltextarchive.pkl
 			ex.	/path/to/archive.csv
 
-	>> Output path: ''')
+	>> Output path: 
+''')
 else:
 	raise Exception("Not a valid input!")
 
@@ -122,7 +126,12 @@ print(f'''
 
 ''')
 
-run.start(in_dir,xpath,mode,batch_size)
+if ab == "B":
+	c = run.config(in_dir,xpath)
+	run.writeArchive(c)
+if ab == "A":
+	c = run.config(in_dir,xpath)
+	run.writeTables(c)
 
 if mode == "archive-from-directory":
 	print(f'''
@@ -130,7 +139,8 @@ if mode == "archive-from-directory":
 		information table from the 
 		full text archive data?
 
-Enter Y/N:	''')
+Enter Y/N:	
+''')
 	info = "".join(input()).strip()
 	if info == "Y":
 		print(f'''
@@ -138,10 +148,12 @@ Enter Y/N:	''')
 			ex.	/full/path/to/fulltextarchive.pkl
 			ex.	/path/to/archive.csv 
 
-Output Path: ''')
-		in_dir = xpath
-		xpath = "".join(input()).strip()
-		run.start(in_dir,xpath,"tables-from-archive",batch_size=2000)
+Output Path: 
+''')
+	in_dir = xpath
+	xpath = "".join(input()).strip()
+	c = run.config(in_dir,xpath)
+	run.writeArchive(c)
 	if info == "N":
 		print(f'''
 			Alacorder completed the task and will now quit.
