@@ -8,20 +8,20 @@ import glob
 import re
 import xlrd
 import openpyxl
-from math import floor
+import math
 import datetime
 import pandas as pd
 import numpy as np
-import PyPDF2 as pdfs
+import PyPDF2 as pypdf
 
 
 
 def getPDFText(path: str) -> str:
 	text = ""
-	pdf = pdfs.PdfReader(path)
+	pdf = pypdf.PdfReader(path)
 	for pg in pdf.pages:
-		text += pg.extract_text() + "\n"
-	return str(text)
+		text += pg.extract_text()
+	return text
 
 def getCaseInfo(text: str):
 	case_num = ""
@@ -39,18 +39,22 @@ def getCaseInfo(text: str):
 	except (IndexError, AttributeError):
 		pass
  
-	#try:
 	if bool(re.search(r'(?a)(VS\.|V\.{1})(.+)(Case)*', text, re.MULTILINE)) == True:
 		name = re.search(r'(?a)(VS\.|V\.{1})(.+)(Case)*', text, re.MULTILINE).group(2).replace("Case Number:","").strip()
 	else:
 		if bool(re.search(r'(?:DOB)(.+)(?:Name)', text, re.MULTILINE)) == True:
 			name = re.search(r'(?:DOB)(.+)(?:Name)', text, re.MULTILINE).group(1).replace(":","").replace("Case Number:","").strip()
-	
-	alias = "" # Add support for PyPDF2 version, in meantime crawl with PDFPlumber version
-
+	if bool(re.search(r'(SSN).{5,75}?(Alias)',text, re.MULTILINE)) == True:
+		alias = re.search(r'(SSN)(.{5,75})(Alias)?', text, re.MULTILINE).group(2).replace(":","").replace("Alias 1","").strip()
+	else:
+		pass
 	try:
 		dob: str = re.search(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB\:)', str(text), re.DOTALL).group(1)
 		phone: str = re.search(r'(?:Phone\:)(.*?)(?:Country)', str(text), re.DOTALL).group(1).strip()
+		if len(phone) < 7:
+			phone = ""
+		if len(phone) > 10 and phone[-3:] == "000":
+			phone = phone[0:9]
 	except (IndexError, AttributeError):
 		dob = ""
 		phone = ""
@@ -77,66 +81,80 @@ def getCaseInfo(text: str):
 	except (IndexError, AttributeError):
 		state = ""
 	
-	address = street_addr + "	" + city + ", " + state + " " + zip_code
-
-	case = [
-		case_num,
-		name,
-		alias,
-		dob,
-		race,
-		sex,
-		address,
-		phone
-		]
-
+	address = street_addr + " " + city + ", " + state + " " + zip_code
+	case = [case_num, name, alias, dob, race, sex, address, phone]
 	return case
 
-def getFeeSheet(text: str):
+def getFeeSheet(text: str, cnum: str):
 	actives = re.findall(r'(ACTIVE.*\$.*)', str(text))
-	rind = range(0, len(actives))
-	fees = pd.DataFrame({'Rows':actives},index=rind)
-	try:
-		totalrow = re.findall(r'(Total.*\$.*)', str(text), re.MULTILINE)[0]
-		tbal = totalrow.split("$")[1].strip().replace("Total: $","").replace(",","").replace(" ","")
-		tdue = totalrow.split("$")[3].strip().replace("$","").replace(",","").replace(" ","")
-	except IndexError:
-		totalrow = ""
-		tbal = ""
-		tdue = ""
-	fees['SRows'] = fees['Rows'].map(lambda x: x.strip().split(" "))
-	fees['DRows'] = fees['Rows'].map(lambda x: x.replace(",","").split("$"))
-	fees['Code'] = fees['SRows'].map(lambda x: x[5] if len(x)>2 else "")
-	fees['Payor'] = fees['SRows'].map(lambda x: x[6] if len(x)>3 else "")
-	fees['AmtDue'] = fees['DRows'].map(lambda x: x[-1] if len(x)>1 else "")
-	fees['AmtPaid'] = fees['DRows'].map(lambda x: x[2] if len(x)>2 else "")
-	fees['Balance'] = fees['DRows'].map(lambda x: x[1] if len(x)>3 else "")
-	fees['AmtHold'] = fees['DRows'].map(lambda x: x[3] if len(x)>4 else "")
-	
-	try:
-		d999 = fees['Balance'][fees.Code == "D999"]
-	except (TypeError, IndexError):
-		d999 = ""
+	if len(actives) == 0:
+		return [np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan]
+	else:
+		rind = range(0, len(actives)+1)
+		try:
+			totalrow = re.findall(r'(Total.*\$.*)', str(text), re.MULTILINE)[0]
+			tbal = totalrow.split("$")[1].strip().replace("Total: $","").replace(",","").replace(" ","")
+			tdue = totalrow.split("$")[3].strip().replace("$","").replace(",","").replace(" ","")
+		except IndexError:
+			totalrow = ""
+			tbal = ""
+			tdue = ""
+		actives.append(totalrow)
+		fees = pd.Series(actives,index=rind,dtype=str)
+		fees_noalpha = fees.map(lambda x: re.sub(r'[^0-9|\.|\s|\$]', "", x))
+		srows = fees.map(lambda x: x.strip().split(" "))
+		drows = fees_noalpha.map(lambda x: x.replace(",","").split("$"))
+		coderows = srows.map(lambda x: str(x[5]) if len(x)>5 else "")
+		payorrows = srows.map(lambda x: str(x[6]) if len(x)>6 else "")
+		amtduerows = drows.map(lambda x: str(x[-1]) if len(x)>1 else "")
+		amtpaidrows = drows.map(lambda x: str(x[2]) if len(x)>2 else "")
+		balancerows = drows.map(lambda x: str(x[1]) if len(x)>3 else "")
+		amtholdrows = drows.map(lambda x: str(x[3]).split(" ")[0] if len(x)>4 else "")
+		istotalrow = fees.map(lambda x: bool(re.search(r'(Total)',x)))
+		# print(coderows, payorrows, amtduerows, amtpaidrows, balancerows, amtholdrows)
 
-	owe_codes = " ".join(fees['Code'][fees.Balance.str.len() > 1])
-	codes = " ".join(fees['Code'])
-	allrows = []
-	allrows.append(actives)
-	allrows.append(totalrow)
-	return [tdue, tbal, d999, owe_codes, codes, allrows]
+		feesheet = pd.DataFrame({
+			'CaseNumber': cnum,
+			'Code': coderows.tolist(),
+			'Payor': payorrows.tolist(),
+			'AmtDue': amtduerows.tolist(),
+			'AmtPaid': amtpaidrows.tolist(),
+			'Balance': balancerows.tolist(),
+			'AmtHold': amtholdrows.tolist(),
+			'Total': istotalrow.tolist()
+			})
 
-def getCharges(text: str):
+
+		try:
+			d999 = feesheet[feesheet['Code']=='D999']['Balance']
+		except (TypeError, IndexError):
+			d999 = ""
+
+		owe_codes = " ".join(feesheet['Code'][feesheet.Balance.str.len() > 1])
+		codes = " ".join(feesheet['Code'])
+		allrows = actives
+		allrows.append(totalrow)
+		allrowstr = "\n".join(allrows)
+		return [tdue, tbal, d999, owe_codes, codes, allrowstr, feesheet]
+
+def getCharges(text: str, cnum: str):
 	# get all charges matches
-	ch = re.findall(r'(\d{3}\s{1}.{1,100}?.{3}-.{3}-.{3}.{0,100}+)', str(text), re.MULTILINE)
+	ch = re.findall(r'(\d{3}\s{1}.{1,100}?.{3}-.{3}-.{3}.{10,75})', str(text), re.MULTILINE)
 	c = []
 	for a in ch:
-		c.append(str(a).replace("Sentences","").replace("Sentence","").replace("SentencesSentence","").replace("Sentence 1","").replace("Financial","").strip())
+		b = str(a).replace("Sentences","").replace("Sentence 1","").replace("SentencesSentence 1","").replace("Sentence","").replace("Financial","")
+		if b[-2:] == " 1" or b[-2:] == " 0":
+			b = b.replace(" 1","").replace(" 0","").strip()
+		if ":" in b:
+			continue
+		c.append(re.sub(r'[a-z]*','', b))
 	cind = range(0, len(c))
 	charges = pd.DataFrame({'Charges': c},index=cind)
+	charges['CaseNumber'] = charges.index.map(lambda x: cnum)
 	# find table fields
 	split_charges = charges['Charges'].map(lambda x: x.split(" "))
 	charges['Num'] = split_charges.map(lambda x: x[0].strip())
-	charges['Code'] = split_charges.map(lambda x: x[1].strip())
+	charges['Code'] = split_charges.map(lambda x: x[1].strip()[0:4])
 	charges['Felony'] = charges['Charges'].map(lambda x: bool(re.search(r'FELONY',x)))
 	charges['Conviction'] = charges['Charges'].map(lambda x: bool(re.search(r'GUILTY|CONVICTED',x)))
 	charges['VRRexception'] = charges['Charges'].map(lambda x: bool(re.search(r'(A ATT|ATTEMPT|S SOLICIT|CONSP)',x)))
@@ -149,7 +167,7 @@ def getCharges(text: str):
 	charges['Disposition'] = charges['Charges'].map(lambda x: bool(re.search(r'\d{2}/\d{2}/\d{4}', x)))
 	charges['CourtActionDate'] = charges['Charges'].map(lambda x: re.search(r'\d{2}/\d{2}/\d{4}', x).group() if bool(re.search(r'\d{2}/\d{2}/\d{4}', x)) else "")
 	charges['CourtAction'] = charges['Charges'].map(lambda x: re.search(r'(BOUND|GUILTY PLEA|PROBATION|WAIVED|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|OTHER|DISMISSED|FORFEITURE|TRANSFER|REMANDED|PROBATION|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', x).group() if bool(re.search(r'(BOUND|GUILTY PLEA|PROBATION|WAIVED|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|OTHER|DISMISSED|FORFEITURE|TRANSFER|REMANDED|PROBATION|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', x)) else "")
-	charges['Cite'] = charges['Charges'].map(lambda x: re.search(r'([^\s]{3}-[^\s]{3}-[^\s]{3}[^s]{0,3}?\)*)', x).group() if bool(re.search(r'([^\s]{3}-[^\s]{3}-[^\s]{3}[^s]{0,3}?\)*)', x)) else re.search(r'(.{3}-.{3}-)',x).group())
+	charges['Cite'] = charges['Charges'].map(lambda x: re.search(r'([^\s]{3}-[^\s]{3}-[^\s]{3}[^s]{0,3}?\)*)', x).group() if bool(re.search(r'([^\s]{3}-[^\s]{3}-[^\s]{3}[^s]{0,3}?\)*)', x)) else re.search(r'(.{3}-.{3}-)',x).group() if bool(re.search(r'(.{3}-.{3}-)',x)) else "")
 	charges['TypeDescription'] = charges['Charges'].map(lambda x: re.search(r'(BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', x).group() if bool(re.search(r'(BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', x)) else "")
 	charges['Category'] = charges['Charges'].map(lambda x: re.search(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', x).group() if bool(re.search(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', x)) else "")
 	charges['Description'] = charges.index.map(lambda x: charges['Charges'][x].replace(charges['Code'][x],"").replace(charges['Cite'][x],"").replace(charges['Category'][x],"").replace(charges['TypeDescription'][x],"").replace(charges['Num'][x],"").replace(charges['CourtAction'][x],"").replace(charges['CourtActionDate'][x],"").replace("Sentences","").replace("Sentence 1","").strip())
@@ -167,14 +185,13 @@ def getCharges(text: str):
 
 	# summary strings
 	convictions = "; ".join(charges[charges.Conviction == True]['Charges'].tolist())
+	conv_codes = " ".join(charges[charges.Conviction == True]['Code'].tolist())
+	charge_codes = " ".join(charges[charges.Disposition == True]['Code'].tolist())
 	dcharges = "; ".join(charges[charges.Disposition == True]['Charges'].tolist())
 	fcharges = "; ".join(charges[charges.Disposition == False]['Charges'].tolist())
 	cerv_convictions = "; ".join(charges[charges.CERV == True][charges.Conviction == True]['Charges'].tolist())
 	pardon_convictions = "; ".join(charges[charges.Pardon == True][charges.Conviction == True]['Charges'].tolist())
 	perm_convictions = "; ".join(charges[charges.Permanent == True][charges.Conviction == True]['Charges'].tolist())
 
-	return [convictions, dcharges, fcharges, cerv_convictions, pardon_convictions, perm_convictions, conviction_ct, charge_ct, cerv_ct, pardon_ct, perm_ct, conv_cerv_ct, conv_pardon_ct, conv_perm_ct]
-
-
-
+	return [convictions, dcharges, fcharges, cerv_convictions, pardon_convictions, perm_convictions, conviction_ct, charge_ct, cerv_ct, pardon_ct, perm_ct, conv_cerv_ct, conv_pardon_ct, conv_perm_ct, charge_codes, conv_codes, "; ".join(charges['Charges']), charges]
 
